================================================
watch-open: Opens a copy of file on every change
================================================

Installing
==========

watch-open can be installed via pip as follows:

::

    pip install watch-open

Usage
=====

::

    python -m watchopen /path/to/file.pdf
    watch-open /path/to/file.pdf
    watch-open /path/to/dir -i "*.pdf" "*.xls"
    
Author
======

Stanislav Doronin <mugisbrows@gmail.com>

License
=======

watch-open is distributed under the terms of MIT license, check `LICENSE` file.

Contributing
============

If you'd like to contribute, fork the project, make changes, and send a pull
request. Have a look at the surrounding code and please, make yours look
alike :-)